==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm2015/lib/MoneyFlowIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MoneyFlowIndexIndicatorStrategy } from "./MoneyFlowIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let MoneyFlowIndexIndicator = /*@__PURE__*/ (() => {
    class MoneyFlowIndexIndicator extends StrategyBasedIndicator {
        get_x5() {
            return 1;
        }
        constructor() {
            super();
        }
        get_yy() {
            return new MoneyFlowIndexIndicatorStrategy();
        }
        get yy() {
            return this.get_yy();
        }
        get_zb() {
            return MoneyFlowIndexIndicator.$;
        }
        get zb() {
            return this.get_zb();
        }
        get zj() {
            return typeGetValue(this.c(MoneyFlowIndexIndicator.zk));
        }
        set zj(a) {
            this.h(MoneyFlowIndexIndicator.zk, a);
        }
        y4() {
            return this.zj;
        }
        zd(a) {
            this.zj = a;
        }
    }
    MoneyFlowIndexIndicator.$t = /*@__PURE__*/ markType(MoneyFlowIndexIndicator, 'MoneyFlowIndexIndicator', StrategyBasedIndicator.$);
    MoneyFlowIndexIndicator.zk = /*@__PURE__*/ StrategyBasedIndicator.zg(14, MoneyFlowIndexIndicator.$);
    return MoneyFlowIndexIndicator;
})();

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/MoneyFlowIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MoneyFlowIndexIndicatorStrategy } from "./MoneyFlowIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let MoneyFlowIndexIndicator = /*@__PURE__*/ (() => {
    class MoneyFlowIndexIndicator extends StrategyBasedIndicator {
        bj() {
            return new MoneyFlowIndexIndicator();
        }
        get_aax() {
            return 1;
        }
        constructor() {
            super();
        }
        get_abq() {
            return new MoneyFlowIndexIndicatorStrategy();
        }
        get abq() {
            return this.get_abq();
        }
        get_ab3() {
            return MoneyFlowIndexIndicator.$;
        }
        get ab3() {
            return this.get_ab3();
        }
        get acb() {
            return typeGetValue(this.c(MoneyFlowIndexIndicator.acc));
        }
        set acb(a) {
            this.h(MoneyFlowIndexIndicator.acc, a);
        }
        abw() {
            return this.acb;
        }
        ab5(a) {
            this.acb = a;
        }
    }
    MoneyFlowIndexIndicator.$t = /*@__PURE__*/ markType(MoneyFlowIndexIndicator, 'MoneyFlowIndexIndicator', StrategyBasedIndicator.$);
    MoneyFlowIndexIndicator.acc = /*@__PURE__*/ StrategyBasedIndicator.ab8(14, MoneyFlowIndexIndicator.$);
    return MoneyFlowIndexIndicator;
})();
